## 1.5.7.1.20250708 (2025-07-08)

[zstd] Update to 1.5.7.1 (#14250)

## 1.5.7.0.20250507 (2025-05-07)

[stubsabot] Bump zstd to 1.5.7.0 (#13946)

## 1.5.6.8.20250506 (2025-05-06)

[stubsabot] Bump zstd to 1.5.6.8 (#13917)

## 1.5.6.7.20250404 (2025-04-04)

[stubsabot] Bump zstd to 1.5.6.7 (#13780)

Release: https://pypi.org/pypi/zstd/1.5.6.7
Homepage: https://github.com/sergey-dryabzhinsky/python-zstd
Repository: https://github.com/sergey-dryabzhinsky/python-zstd
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/zstd
Diff: https://github.com/sergey-dryabzhinsky/python-zstd/compare/v1.5.6.6...v1.5.6.7

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 4.
 - Total lines of Python code deleted: 3.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 1.5.6.6.20250306 (2025-03-06)

[stubsabot] Bump zstd to 1.5.6.6 (#13584)

Release: https://pypi.org/pypi/zstd/1.5.6.6
Homepage: https://github.com/sergey-dryabzhinsky/python-zstd
Repository: https://github.com/sergey-dryabzhinsky/python-zstd
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/zstd
Diff: https://github.com/sergey-dryabzhinsky/python-zstd/compare/v1.5.6.5...v1.5.6.6

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 12.
 - Total lines of Python code deleted: 11.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 1.5.6.5.20250304 (2025-03-04)

[stubsabot] Bump zstd to 1.5.6.5 (#13569)

## 1.5.6.4.20250224 (2025-02-24)

[stubsabot] Bump zstd to 1.5.6.4 (#13527)

Release: https://pypi.org/pypi/zstd/1.5.6.4
Homepage: https://github.com/sergey-dryabzhinsky/python-zstd
Repository: https://github.com/sergey-dryabzhinsky/python-zstd
Typeshed stubs: https://github.com/python/typeshed/tree/main/stubs/zstd
Diff: https://github.com/sergey-dryabzhinsky/python-zstd/compare/v1.5.6.3...v1.5.6.4

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 26.
 - Total lines of Python code deleted: 5.

If stubtest fails for this PR:
- Leave this PR open (as a reminder, and to prevent stubsabot from opening another PR)
- Fix stubtest failures in another PR, then close this PR

Note that you will need to close and re-open the PR in order to trigger CI

Co-authored-by: stubsabot <>

## 1.5.6.3.20250218 (2025-02-18)

Bump zstd to 1.5.6.3 (#13506)

## 1.5.6.2.20250126 (2025-01-26)

Bump zstd to 1.5.6.2 (#13434)

## 1.5.6.1.20250123 (2025-01-23)

zstd: pin version (#13428)

## 1.5.0.20240311 (2024-03-11)

Use PEP 570 syntax in third party stubs (#11554)

## 1.5.0.3 (2023-07-20)

Add an upstream_repository field to METADATA.toml (#10487)

Closes: #10478

## 1.5.0.2 (2023-03-24)

[zstd] Add ZSTD_(max_)threads_count methods (#9938)

Closes: #9935

## 1.5.0.1 (2023-02-21)

Stubtest settings: change `ignore_missing_stub` default to `false` (#9779)

If you're reading about this commit from an autogenerated changelog entry, this should have no user-visible impact on how the stubs are interpreted by a type checker; it's just an internal change to how typeshed's tests work.

## 1.5.0.0 (2023-02-01)

Add stubs for `zstd` (#9484)

Co-authored-by: Jelle Zijlstra <jelle.zijlstra@gmail.com>

